'use strict';

var fs = require('fs');
var path = require('path');

var TitanFactory = module.exports = {};

TitanFactory.open = function (java, directoryOrConfigFile) {
  var GraphDatabaseConfiguration = java.import('com.thinkaurelius.titan.graphdb.configuration.GraphDatabaseConfiguration');
  var StandardTitanGraph = java.import('com.thinkaurelius.titan.graphdb.database.StandardTitanGraph');
  var BaseConfiguration = java.import('org.apache.commons.configuration.BaseConfiguration');

  var Class = java.import('java.lang.Class');
  var Order = java.import('com.thinkaurelius.titan.core.Order');
  var ArrayListClazz = Class.forNameSync('java.util.ArrayList');
  var IntegerClazz = Class.forNameSync('java.lang.Integer');
  var StringClazz = Class.forNameSync('java.lang.String');
  var LongClazz = Class.forNameSync('java.lang.Long');
  var VertexClazz = java.getClassLoader().loadClassSync('com.tinkerpop.blueprints.Vertex');
  var EdgeClazz = java.getClassLoader().loadClassSync('com.tinkerpop.blueprints.Edge');
  var GeoshapeClazz = java.getClassLoader().loadClassSync('com.thinkaurelius.titan.core.attribute.Geoshape');

  // open the graph. if we are passing a configuration file, load it up.
  // else, create a configuration with the supplied directory as the root
  // for the local storage and es backends.
  var graphConfig;
  var stat = fs.statSync(directoryOrConfigFile);
  if (stat.isDirectory()) {
    var config = new BaseConfiguration();

    // configure the local backend
    config.setPropertySync('storage.backend', 'local');
    config.setPropertySync('storage.directory', directoryOrConfigFile);

    // configuring elastic search index
    config.setPropertySync('storage.index.search.backend', 'elasticsearch');
    config.setPropertySync('storage.index.search.local-mode', true);
    config.setPropertySync('storage.index.search.client-only', false);
    config.setPropertySync('storage.index.search.directory', path.join(directoryOrConfigFile, 'es'));

    graphConfig = new GraphDatabaseConfiguration(config);
  } else {
    graphConfig = new GraphDatabaseConfiguration(directoryOrConfigFile);
  }

  // initialize the graph
  return new StandardTitanGraph(graphConfig);
};
